@@ -39,7 +39,7 @@ require 5.013002;
 use strict;
 use warnings FATAL => 'all';
 
-my $url2pkg_pkgsrcdir = '/mnt/earmv7hf/pkgsrc';
+my $url2pkg_pkgsrcdir = '/root/pkgsrc.21Q1';
 
 BEGIN {
 	use Exporter;
